@@ -17,6 +17,7 @@
 
 import re
 import codecs
+import unicodedata
 from copy import deepcopy
 from lettuce import strings
 from lettuce import languages
@@ -180,13 +181,12 @@ class Step(object):
             ("'", re.compile(r"('[^']+')")), # single quotes
         ]
 
-        matched = False
         attribute_names = []
         for char, group in groups:
             match_groups = group.search(self.original_sentence)
 
             if match_groups:
-                matched = True
+
                 for index, match in enumerate(group.findall(sentence)):
                     if char == "'":
                         char = re.escape(char)
@@ -196,9 +196,10 @@ class Step(object):
                     method_name = method_name.replace(match, group_name)
                     attribute_names.append(group_name)
 
-        if not matched:
-            sentence = re.escape(sentence).replace(r'\ ', ' ')
 
+
+        method_name = unicodedata.normalize('NFKD', method_name) \
+                      .encode('ascii', 'ignore')
         method_name = '%s(step%s)' % (
             "_".join(re.findall("\w+", method_name)).lower(),
             attribute_names and (", %s" % ", ".join(attribute_names)) or ""
@@ -699,13 +700,23 @@ class Feature(object):
 
         return scenarios, description
 
-    def run(self, ignore_case=True):
+    def run(self, scenarios=None, ignore_case=True):
         for callback in CALLBACK_REGISTRY['feature']['before_each']:
             callback(self)
 
         scenarios_ran = []
 
-        [scenarios_ran.extend(scenario.run(ignore_case)) for scenario in self.scenarios]
+        if isinstance(scenarios, (tuple, list)):
+            if all(map(lambda x: isinstance(x, int), scenarios)):
+                scenarios_to_run = scenarios
+        else:
+            scenarios_to_run = range(1, len(self.scenarios) + 1)
+
+        for index, scenario in enumerate(self.scenarios):
+            if scenarios_to_run and (index + 1) not in scenarios_to_run:
+                continue
+
+            scenarios_ran.extend(scenario.run(ignore_case))
 
         for callback in CALLBACK_REGISTRY['feature']['after_each']:
             callback(self)
